package org.commonjava.tensor.ispn.data.store;

import org.commonjava.tensor.data.TensorDataException;
import org.commonjava.tensor.data.store.IndexStore;
import org.infinispan.Cache;
import org.infinispan.manager.CacheContainer;

public class CacheIndexStore<K, V>
    implements IndexStore<K, V>
{

    private final Cache<K, V> cache;

    public CacheIndexStore( final String name, final CacheContainer container )
    {
        this.cache = container.getCache( name );
        cache.start();
    }

    @Override
    public V store( final K key, final V value )
    {
        return cache.put( key, value );
    }

    @Override
    public V get( final K key )
    {
        return cache.get( key );
    }

    @Override
    public void clear()
    {
        cache.clear();
    }

    @Override
    public boolean contains( final K key )
    {
        return cache.containsKey( key );
    }

    @Override
    public V remove( final K key )
        throws TensorDataException
    {
        return cache.remove( key );
    }

}
